@@ -1,7 +1,7 @@
 /***************************************************************************
-                          cssprfile.h  -  description
-                             -------------------
- ***************************************************************************/
+                         cssprfile.h  -  description
+                            -------------------
+***************************************************************************/
 
 /***************************************************************************
  *                                                                         *
@@ -21,18 +21,21 @@
   *@author Rene Dudfield
   */
 
-class CSSPRFile : public FilePlugin  {
- public:
-  CSSPRFile();
-  ~CSSPRFile();
-	
-  void importData(ifstream &);
-  void exportData(ofstream &);
-  void writeSprite(Object *o, ofstream &out);
+class CSSPRFile : public FilePlugin
+{
+   public:
+      CSSPRFile();
+      ~CSSPRFile();
 
-// protected:
+      void importData( ifstream & );
+      void exportData( ofstream & );
+      void writeSprite( Object *o, ofstream &out );
 
-};
+      // protected:
+
+}
+
+;
 
 
 #endif
