@@ -1,10 +1,10 @@
 /***************************************************************************
-                          ribfile.h  -  description
-                             -------------------
-    begin                : Sun Aug 20 2000
-    copyright            : (C) 2000 by Jon Anderson
-    email                : janderson@onelink.com
- ***************************************************************************/
+                         ribfile.h  -  description
+                            -------------------
+   begin                : Sun Aug 20 2000
+   copyright            : (C) 2000 by Jon Anderson
+   email                : janderson@onelink.com
+***************************************************************************/
 
 /***************************************************************************
  *                                                                         *
@@ -24,22 +24,23 @@
   *@author Jon Anderson
   */
 
-class RIBFile : public FilePlugin  {
-public: 
-	RIBFile();
-	~RIBFile();
-	
-	void exportData(ofstream &);
+class RIBFile : public FilePlugin
+{
+   public:
+      RIBFile();
+      ~RIBFile();
 
-protected:
+      void exportData( ofstream & );
+
+   protected:
+
+      void writeMeshAsPointsPolygons( Mesh *m, ofstream &out );
+      void writeMeshAsPolygons( Mesh *m, ofstream &out );
+
+      void writeSurface( NurbsSurface *, ofstream & );
+      void writeCamera( Camera *, ofstream & );
 
-	void writeMeshAsPointsPolygons(Mesh *m, ofstream &out);
-	void writeMeshAsPolygons(Mesh *m, ofstream &out);
 
-	void writeSurface(NurbsSurface *, ofstream &);
-	void writeCamera(Camera *, ofstream &);
-	
-	
 };
 
 #endif
